@@ -11,10 +11,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from django.conf.urls import url  # noqa
+from django.conf.urls import url
 
-from monitoring.overview import views
 from monitoring.config import local_settings as settings
+from monitoring.overview import views
 
 
 urlpatterns = [
