@@ -281,12 +281,8 @@ class MonascaProxyView(TemplateView):
                 # the `url` dimension of the service_status check.
                 dimension_name_value = dimension.split(':', 1)
                 if len(dimension_name_value) == 2:
-                    if six.PY2:
-                        name = dimension_name_value[0].encode('utf8')
-                        value = dimension_name_value[1].encode('utf8')
-                    else:
-                        name = dimension_name_value[0]
-                        value = dimension_name_value[1]
+                    name = dimension_name_value[0].encode('utf8')
+                    value = dimension_name_value[1].encode('utf8')
                     dim_dict[name] = urllib.parse.unquote(value)
                 else:
                     raise Exception('Dimensions are malformed')
