@@ -31,12 +31,6 @@ warnings.filterwarnings('ignore', 'With-statements now directly support '
                         r'^tuskar_ui[.].*[._]tests$')
 
 
-def create_stubs(stubs_to_create=None):
-    if stubs_to_create is None:
-        stubs_to_create = {}
-    return helpers.create_stubs(stubs_to_create)
-
-
 class MonitoringTestsMixin(object):
     def _setup_test_data(self):
         super(MonitoringTestsMixin, self)._setup_test_data()
